@@ -11,7 +11,7 @@ def list_all_feed_pks():
     return list(pk_ for (pk_,) in dbconnection.get_session().query(models.Feed.pk))
 
 
-def list_all_autoupdating():
+def list_all_auto_updating():
     """
     List all auto-updating Feeds.
 
@@ -21,7 +21,8 @@ def list_all_autoupdating():
     query = (
         session.query(models.Feed)
         .join(models.System, models.System.pk == models.Feed.system_pk)
-        .filter(models.Feed.auto_update_on)
+        .filter(models.Feed.auto_update_enabled)
+        .filter(models.System.auto_update_enabled)
         .filter(models.System.status == models.System.SystemStatus.ACTIVE)
     )
     return query.all()
@@ -120,3 +121,18 @@ def trim_feed_updates(feed_pk, before_datetime):
         )
     )
     dbconnection.get_session().execute(query)
+
+
+def delete_in_system_by_id(system_id, feed_id):
+    """
+    Delete a Feed from the DB whose ID is given.
+
+    :return: True if an entity was found and deleted, false if no such
+     entity exists
+    """
+    session = dbconnection.get_session()
+    entity = get_in_system_by_id(system_id, feed_id)
+    if entity is None:
+        return False
+    session.delete(entity)
+    return True
